package com.jiuqi.script.rhino;

import java.lang.reflect.Method;
import java.util.Map;
import org.mozilla.javascript.Callable;
import org.mozilla.javascript.Context;
import org.mozilla.javascript.Scriptable;
import org.mozilla.javascript.ScriptableObject;

public class LimitedScriptObject extends ScriptableObject {
   private static final long serialVersionUID = 8048574707866032033L;
   private static final Object[] emptyArray = new Object[0];
   private Object self;
   private Map methods;

   public LimitedScriptObject(Object obj, Map methods) {
      this.self = obj;
      this.methods = methods;
   }

   public String getClassName() {
      return "LimitedScriptObject";
   }

   public Object[] getAllIds() {
      return this.getIds();
   }

   public Object[] getIds() {
      return this.methods.keySet().toArray();
   }

   public Object get(String name, Scriptable start) {
      final Method m = (Method)this.methods.get(name);
      if (m != null) {
         return new Callable() {
            public Object call(Context context, Scriptable scope, Scriptable thisObj, Object[] args) {
               try {
                  if (args == null) {
                     return m.invoke(LimitedScriptObject.this.self, LimitedScriptObject.emptyArray);
                  } else {
                     Object[] newArgs = new Object[args.length];

                     for(int i = 0; i < args.length; ++i) {
                        newArgs[i] = ScriptHelper._toJava(args[i], scope);
                     }

                     return m.invoke(LimitedScriptObject.this.self, newArgs);
                  }
               } catch (Throwable var7) {
                  Throwable e = var7;
                  e.printStackTrace();
                  throw new RuntimeException(e);
               }
            }
         };
      } else {
         String firstChar = name.substring(0, 1);
         firstChar = firstChar.toUpperCase();
         String getter = "get" + firstChar + name.substring(1);
         Method m1 = (Method)this.methods.get(getter);
         if (m1 == null) {
            throw new IllegalArgumentException("Unknown method or property:" + name);
         } else {
            Object result = null;

            try {
               result = m1.invoke(this.self, emptyArray);
            } catch (Exception var9) {
               Exception e = var9;
               e.printStackTrace();
            }

            return result;
         }
      }
   }

   public boolean has(String name, Scriptable start) {
      return this.methods.containsKey(name);
   }
}
